@@ -1,8 +1,5 @@
 package Elastic::Model::Results::Scrolled;
-{
-  $Elastic::Model::Results::Scrolled::VERSION = '0.27';
-}
-
+$Elastic::Model::Results::Scrolled::VERSION = '0.28';
 use Carp;
 use Moose;
 with 'Elastic::Model::Role::Results';
@@ -13,7 +10,7 @@ use namespace::autoclean;
 #===================================
 has '_scroll' => (
 #===================================
-    isa    => 'Elasticsearch::Compat::ScrolledSearch',
+    isa    => 'Search::Elasticsearch::Compat::ScrolledSearch',
     is     => 'ro',
     writer => '_set_scroll',
 );
@@ -82,13 +79,15 @@ sub _fetch_until {
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Elastic::Model::Results::Scrolled - An iterator over unbounded search results
 
 =head1 VERSION
 
-version 0.27
+version 0.28
 
 =head1 SYNOPSIS
 
@@ -433,7 +432,7 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Clinton Gormley.
+This software is copyright (c) 2014 by Clinton Gormley.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
