@@ -1,8 +1,5 @@
 package Elastic::Model::Role::Store;
-{
-  $Elastic::Model::Role::Store::VERSION = '0.27';
-}
-
+$Elastic::Model::Role::Store::VERSION = '0.28';
 use Moose::Role;
 
 use Elastic::Model::Types qw(ES);
@@ -74,13 +71,15 @@ sub bulk {
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Elastic::Model::Role::Store - Elasticsearch backend for document read/write requests
 
 =head1 VERSION
 
-version 0.27
+version 0.28
 
 =head1 DESCRIPTION
 
@@ -102,7 +101,7 @@ Returns the connection to Elasticsearch.
     $result = $store->get_doc($uid, %args);
 
 Retrieves the doc specified by the L<$uid|Elastic::Model::UID> from
-Elasticsearch, by calling L<Elasticsearch/"get()">. Throws an exception
+Elasticsearch, by calling L<Search::Elasticsearch::Compat/"get()">. Throws an exception
 if the document does not exist.
 
 =head2 doc_exists()
@@ -110,7 +109,7 @@ if the document does not exist.
     $bool = $store->doc_exists($uid, %args);
 
 Checks whether the doc exists in ElastciSearch. Any C<%args> are passed through
-to L<Elasticsearch/exists()>.
+to L<Search::Elasticsearch::Compat/exists()>.
 
 =head2 create_doc()
 
@@ -118,7 +117,7 @@ to L<Elasticsearch/exists()>.
 
 Creates a doc in the Elasticsearch backend and returns the raw result.
 Throws an exception if a doc with the same L<$uid|Elastic::Model::UID>
-already exists.  Any C<%args> are passed to L<Elasticsearch/"create()">
+already exists.  Any C<%args> are passed to L<Search::Elasticsearch::Compat/"create()">
 
 =head2 index_doc()
 
@@ -127,7 +126,7 @@ already exists.  Any C<%args> are passed to L<Elasticsearch/"create()">
 Updates (or creates) a doc in the Elasticsearch backend and returns the raw
 result. Any failure throws an exception.  If the L<version|Elastic::Model::UID/"version">
 number does not match what is stored in Elasticsearch, then a conflict exception
-will be thrown.  Any C<%args> will be passed to L<Elasticsearch/"index()">.
+will be thrown.  Any C<%args> will be passed to L<Search::Elasticsearch::Compat/"index()">.
 For instance, to overwrite a document regardless of version number, you could
 do:
 
@@ -140,7 +139,7 @@ do:
 Deletes a doc in the Elasticsearch backend and returns the raw
 result. Any failure throws an exception.  If the L<version|Elastic::Model::UID/"version">
 number does not match what is stored in Elasticsearch, then a conflict exception
-will be thrown.  Any C<%args> will be passed to L<Elasticsearch/"delete()">.
+will be thrown.  Any C<%args> will be passed to L<Search::Elasticsearch::Compat/"delete()">.
 
 =head2 bulk()
 
@@ -152,19 +151,19 @@ will be thrown.  Any C<%args> will be passed to L<Elasticsearch/"delete()">.
     );
 
 Performs several actions in a single request. Any %agrs will be passed to
-L<Elasticsearch/bulk()>.
+L<Search::Elasticsearch::Compat/bulk()>.
 
 =head2 search()
 
     $results = $store->search(@args);
 
-Performs a search, passing C<@args> to L<Elasticsearch/"search()">.
+Performs a search, passing C<@args> to L<Search::Elasticsearch::Compat/"search()">.
 
 =head2 scrolled_search()
 
     $results = $store->scrolled_search(@args);
 
-Performs a scrolled search, passing C<@args> to L<Elasticsearch/"scrolled_search()">.
+Performs a scrolled search, passing C<@args> to L<Search::Elasticsearch::Compat/"scrolled_search()">.
 
 =head1 AUTHOR
 
@@ -172,7 +171,7 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Clinton Gormley.
+This software is copyright (c) 2014 by Clinton Gormley.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
