@@ -1,8 +1,5 @@
 package Elastic::Model::View;
-{
-  $Elastic::Model::View::VERSION = '0.27';
-}
-
+$Elastic::Model::View::VERSION = '0.28';
 use Moose;
 
 use Carp;
@@ -524,13 +521,15 @@ sub _build_delete {
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Elastic::Model::View - Views to query your docs in Elasticsearch
 
 =head1 VERSION
 
-version 0.27
+version 0.28
 
 =head1 SYNOPSIS
 
@@ -751,12 +750,12 @@ one or more types.
     \%query   = $view->query
 
 Specify the query to run in the native
-L<Elasticsearch query DSL|http://www.Elasticsearch.org/guide/reference/query-dsl/>
+L<Elasticsearch query DSL|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/query-dsl.html>
 or use C<queryb()> to specify your query  with the more Perlish
 L<Elastic::Model::SearchBuilder> query syntax.
 
 By default, the query will
-L<match all docs|http://www.Elasticsearch.org/guide/reference/query-dsl/match-all-query.html>.
+L<match all docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/query-dsl-match-all-query.html>.
 
 =head2 filter
 
@@ -774,9 +773,9 @@ You can specify a filter to apply to the query results using either
 the native Elasticsearch query DSL or, use C<filterb()> to specify your
 filter with the more Perlish L<Elastic::Model::SearchBuilder> DSL.
 If a filter is specified, it will be combined with the L</query>
-as a L<filtered query|http://www.Elasticsearch.org/guide/reference/query-dsl/filtered-query.html>,
+as a L<filtered query|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/query-dsl-filtered-query.html>,
 or (if no query is specified) as a
-L<constant score|http://www.Elasticsearch.org/guide/reference/query-dsl/constant-score-query.html>
+L<constant score|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/query-dsl-constant-score-query.html>
 query.
 
 =head2 post_filter
@@ -791,7 +790,7 @@ query.
 
     \%filter  = $view->post_filter;
 
-L<Post-filters|http://www.Elasticsearch.org/guide/reference/api/search/filter.html>
+L<Post-filters|http://www.elasticsearch.org/guide/en/elasticsearch/reference/0.90/search-request-post-filter.html>
 filter the results AFTER any L</facets> have been calculated.  In the above
 example, the facets would be calculated on all values of C<tag>, but the
 results would then be limited to just those docs where C<tag == perl>.
@@ -817,7 +816,7 @@ L<Elastic::Model::SearchBuilder> DSL.
 By default, results are sorted by "relevance" (C<< _score => 'desc' >>).
 You can specify multiple sort arguments, which are applied in order, and
 can include scripts or geo-distance.
-See L<http://www.Elasticsearch.org/guide/reference/api/search/sort.html> for
+See L<http://www.elasticsearch.org/guide/en/elasticsearch/reference/0.90/search-request-sort.html> for
 more information.
 
 B<Note:> Sorting cannot be combined with L</scan()>.
@@ -869,7 +868,7 @@ from the query generated from L</query> and L</filter>.  If you want to filter
 your query results down further after calculating your facets, you can
 use L</post_filter>.
 
-See L<http://www.Elasticsearch.org/guide/reference/api/search/facets/> for
+See L<http://www.elasticsearch.org/guide/en/elasticsearch/reference/0.90/search-facets.html> for
 an explanation of what facets are available.
 
 =head2 highlight
@@ -881,7 +880,7 @@ an explanation of what facets are available.
     );
 
 Specify which fields should be used for
-L<highlighted snippets|http://www.Elasticsearch.org/guide/reference/api/search/highlighting.html>.
+L<highlighted snippets|http://www.elasticsearch.org/guide/en/elasticsearch/reference/0.90/search-request-highlighting.html>.
 to your search results. You can pass just a list of fields, or fields with
 their field-specific settings. These values are used to set the C<fields>
 parameter in L</highlighting>.
@@ -900,7 +899,7 @@ which should be applied to all of the fields set in L</highlight> (although
 you can override these settings for individual fields by passing field settings
 to L</highlight>).
 
-See L<http://www.Elasticsearch.org/guide/reference/api/search/highlighting.html>.
+See L<http://www.elasticsearch.org/guide/en/elasticsearch/reference/0.90/search-request-highlighting.html>.
 for more about how highlighting works, and L<Elastic::Model::Result/highlight>
 for how to retrieve the highlighted snippets.
 
@@ -910,11 +909,11 @@ for how to retrieve the highlighted snippets.
 
     $new_view = $view->fields('title','content');
 
-By default, searches will return the L<_source|http://www.Elasticsearch.org/guide/reference/mapping/source-field.html>
+By default, searches will return the L<_source|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/mapping-source-field.html>
 field which contains the whole document, allowing Elastic::Model to inflate
 the original object without having to retrieve the document separately. If you
 would like to just retrieve a subset of fields, you can specify them in
-L</fields>. See L<http://www.Elasticsearch.org/guide/reference/api/search/fields.html>.
+L</fields>. See L<http://www.elasticsearch.org/guide/en/elasticsearch/reference/0.90/search-request-fields.html>.
 
 B<Note:> If you do specify any fields, and you DON'T include C<'_source'> then the
 C<_source> field won't be returned, and you won't be able to retrieve the original
@@ -937,9 +936,9 @@ object without requesting it from Elasticsearch in a separate (but automatic) st
     \%fields  = $view->script_fields;
     \%defn    = $view->get_script_field($name);
 
-L<Script fields|http://www.Elasticsearch.org/guide/reference/api/search/script-fields.html>
+L<Script fields|http://www.elasticsearch.org/guide/en/elasticsearch/reference/0.90/search-request-script-fields.html>
 can be generated using the L<mvel|http://mvel.codehaus.org/Language+Guide+for+2.0>
-scripting language. (You can also use L<Javascript, Python and Java|http://www.Elasticsearch.org/guide/reference/modules/scripting>.)
+scripting language. (You can also use L<Javascript, Python and Java|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/modules-scripting.html>.)
 
 =head2 include_paths / exclude_paths
 
@@ -960,7 +959,7 @@ The partial objects returned when L<Elastic::Model::Results/as_partials()>
 is in effect function exactly as real objects, except that they cannot
 be saved.
 
-See C<Partial fields> on L<http://www.Elasticsearch.org/guide/reference/api/search/fields.html>.
+See C<Partial fields> on L<http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/search-request-fields.html#partial>.
 
 =head2 routing
 
@@ -1002,7 +1001,7 @@ Exclude results whose score (relevance) is less than the specified number.
     $new_view = $view->preference( '_local' );
 
 Control which node should return search results. See
-L<http://www.Elasticsearch.org/guide/reference/api/search/preference.html> for more.
+L<http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/search-request-preference.html> for more.
 
 =head2 timeout
 
@@ -1061,7 +1060,7 @@ L<Elastic::Model::Result/explain> to view the output.
     \@groups  = $view->stats;
 
 The statistics for each search can be aggregated by C<group>. These stats
-can later be retrieved using L<Elasticsearch/index_stats()>.
+can later be retrieved using L<Search::Elasticsearch::Compat/index_stats()>.
 
 =head2 search_builder
 
@@ -1099,7 +1098,7 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Clinton Gormley.
+This software is copyright (c) 2014 by Clinton Gormley.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
